==> apache-ambari-2.6.2-src.tar.gz: apache-ambari-2.6.2-src/ambari-server/src/main/java/org/apache/ambari/server/security/ldap/LdapSyncDto.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ambari.server.security.ldap;

import java.util.HashSet;
import java.util.Set;

/**
 * Pojo with information about LDAP groups and users.
 */
public class LdapSyncDto {
  /**
   * LDAP groups.
   */
  private Set<LdapGroupDto> groups = new HashSet<LdapGroupDto>();

  /**
   * LDAP users.
   */
  private Set<LdapUserDto> users = new HashSet<LdapUserDto>();

  /**
   * Get the LDAP groups.
   *
   * @return the LDAP groups
   */
  public Set<LdapGroupDto> getGroups() {
    return groups;
  }

  /**
   * Set the LDAP groups.
   *
   * @param groups the LDAP groups
   */
  public void setGroups(Set<LdapGroupDto> groups) {
    this.groups = groups;
  }

  /**
   * Get the LDAP users.
   *
   * @return the LDAP users
   */
  public Set<LdapUserDto> getUsers() {
    return users;
  }

  /**
   * Set the LDAP users.
   *
   * @param users the LDAP users
   */
  public void setUsers(Set<LdapUserDto> users) {
    this.users = users;
  }
}

==> apache-ambari-3.0.0-src.tar.gz: apache-ambari-3.0.0-src/ambari-server/src/main/java/org/apache/ambari/server/security/ldap/LdapSyncDto.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ambari.server.security.ldap;

import java.util.HashSet;
import java.util.Set;

/**
 * Pojo with information about LDAP groups and users.
 */
public class LdapSyncDto {
  /**
   * LDAP groups.
   */
  private Set<LdapGroupDto> groups = new HashSet<>();

  /**
   * LDAP users.
   */
  private Set<LdapUserDto> users = new HashSet<>();

  /**
   * Get the LDAP groups.
   *
   * @return the LDAP groups
   */
  public Set<LdapGroupDto> getGroups() {
    return groups;
  }

  /**
   * Set the LDAP groups.
   *
   * @param groups the LDAP groups
   */
  public void setGroups(Set<LdapGroupDto> groups) {
    this.groups = groups;
  }

  /**
   * Get the LDAP users.
   *
   * @return the LDAP users
   */
  public Set<LdapUserDto> getUsers() {
    return users;
  }

  /**
   * Set the LDAP users.
   *
   * @param users the LDAP users
   */
  public void setUsers(Set<LdapUserDto> users) {
    this.users = users;
  }
}
